#line 2 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/build/config/flexsphinxql.c"

#line 4 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/build/config/flexsphinxql.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 156
#define YY_END_OF_BUFFER 157
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[609] =
    {   0,
        0,    0,    0,    0,  157,  155,  153,  153,  155,  155,
      155,  155,  140,  155,  155,  155,  155,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  155,    2,
      156,    2,  153,  130,    0,  135,    0,    0,  137,  154,
        1,  136,  140,  145,  145,  134,  132,  131,  133,    0,
      146,  146,  146,  146,  144,    0,  144,  144,  144,  144,
       10,  144,  144,  144,  144,  144,   19,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  144,  144,   53,   54,   62,  144,

      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,   82,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  115,  144,
      144,  144,  144,  144,  144,  144,  144,  144,    0,    0,
        0,    3,    0,  138,  138,  154,  136,    0,    0,  139,
      147,  146,  146,  141,  146,  152,    4,  144,    6,  144,
        8,    9,   11,  144,   14,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,   37,  144,  144,  144,  144,  144,  144,   44,
      144,  144,  144,  144,  144,  144,  144,  144,   60,  144,

      144,  144,  144,  144,  144,  144,  144,   71,  144,   73,
       74,  144,  144,   78,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  102,  144,  144,  144,  144,  110,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  144,  144,    0,    0,  150,    0,  138,
        0,  137,    0,  136,  139,    0,  147,  146,  146,  152,
      144,  144,  144,  144,  144,  144,  144,   18,   20,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
       34,  144,  144,   39,  144,  144,  144,  144,   45,  144,

      144,  144,  144,  144,  144,  144,  144,   61,  144,   64,
       65,  144,   67,  144,   68,  144,   72,  144,  144,   79,
      144,  144,   84,  144,  144,  144,   89,   90,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  105,  144,  144,  144,  144,  144,  144,  144,  144,
      117,  144,  119,  144,  144,  144,  144,  144,  144,  144,
      144,  128,    0,  151,  149,  137,  148,  146,  146,    5,
        7,  144,  144,   15,  144,  144,  144,   22,  144,  144,
      144,  144,   29,  144,  144,   32,  144,  144,  144,  144,
       40,   41,   42,   43,  144,  144,   48,  144,  144,   55,

      144,  144,  144,   66,   69,   70,   75,   77,  144,  144,
       83,  144,  144,  144,  144,   91,  144,   96,  144,  144,
      144,  144,  144,  144,  144,  144,  144,  144,  107,  144,
      144,  144,  112,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,  127,  144,  148,  143,  146,   12,  144,
      144,   17,  144,  144,  144,   26,   27,   30,  144,   33,
      144,  144,   38,  144,   47,  144,  144,   51,  144,  144,
      144,   58,  144,  144,  144,  144,   80,   85,  144,  144,
      144,   93,  144,  144,  144,  144,  144,  100,  144,  144,
      144,  106,  108,  109,  144,  113,  144,  144,  144,  144,

      121,  122,  144,  144,  144,  126,  129,  142,  144,   16,
      144,   23,   24,  144,  144,  144,  144,  144,  144,   49,
      144,  144,   56,   57,   59,  144,   76,  144,   86,   87,
      144,  144,  144,   95,   97,  144,   99,  144,  104,  144,
      144,  114,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  144,  144,   35,   36,   46,  144,  144,  144,   81,
       88,  144,  144,   98,  144,  103,  144,  144,  118,  144,
      144,  144,  125,  144,   21,   25,   28,   31,  144,   52,
       63,  144,  144,  144,  144,  144,  144,  123,  144,   13,
      144,  144,   94,  144,  111,  144,  144,  144,  144,   92,

      144,  116,  120,  144,   50,  101,  124,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    1,    1,    1,    1,    1,    5,    1,
        1,    6,    7,    1,    8,    9,   10,   11,   11,   11,
       11,   12,   11,   13,   11,   11,   11,   14,    1,   15,
       16,   17,    1,   18,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
        1,   45,    1,    1,   46,   47,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       62,   63,   35,   64,   65,   66,   67,   68,   69,   70,
       71,   72,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[73] =
    {   0,
        1,    2,    2,    1,    1,    1,    1,    1,    3,    1,
        4,    4,    4,    5,    1,    1,    1,    6,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    1,    7,    8,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7
    } ;

static yyconst flex_uint16_t yy_base[629] =
    {   0,
        0,    0,   70,   71, 1786, 1787,   76,   78, 1769,   70,
       80, 1778,   75, 1767,   73, 1766,   76,  132,   81,  187,
      238, 1766,  289,   71,   86,   88,   85,  128,  343,  163,
       95,  130,  193,  397,  455,  142,   92,  249,  197, 1787,
     1787, 1769,  110, 1787,   91, 1787,  118,  216,  221,    0,
     1787,  225,  269, 1766,  276, 1787, 1787, 1787, 1787,    0,
        0,  105,  153,  162, 1760,    0,  240,  244,  279,  284,
      229,  293,  167,  298,  285,  233, 1757,  299,  301,  302,
      347,  319,  336,  359,  361,  333,  330,  383,  370,  151,
      332,  208,  379,  405,  320,  407, 1756,  439,  413,  401,

      417,  403,  425,  329,  459,  420,  433,  448,  452,  464,
      446,  478,  475,  492,  488,  482,  502,  550,  479,  504,
      553,  506,  516,  509,  518,  521,  367,  486, 1753,  560,
      532,  526,  571,  593,  578,  538,  573,  583,  590, 1719,
      584, 1787,  123,    0,  625,    0,  628,  647,  632,  652,
     1753,    0,  132,    0,  395,    0, 1747,  614, 1743,  601,
     1742, 1739, 1738,  648, 1735,  642,  633,  652,  656,  657,
      612,  636,  658,  671,  659,  667,  663,  669,  664,  677,
      692,  680, 1734,  700,  690,  711,  695,  707,  708, 1731,
      719,  722,  721,  713,  730,  723,  725,  733,  745,  737,

      726,  750,  748,  751,  761,  755,  762, 1730,  776, 1727,
     1726,  767,  770, 1723,  780,  787,  785,  777,  528,  792,
      804,  799,  801,  813,  805,  815,  812,  821,  816,  826,
      827,  835,  820,  828,  848,  822,  847,  854,  855, 1722,
      850,  864,  856,  839,  875,  858,  882,  883,  870,  885,
      887,  890,  891,  892,  903, 1686, 1680, 1787, 1679,    0,
      921,  927,  935,  948,  951,    0, 1713,  881,  896,    0,
      905,  916,  951,  940,  941,  943,  954, 1707, 1705,  955,
      956,  961,  962,  963,  964,  968,  969,  970,  975,  973,
      990,  965,  979, 1686,  974,  994,  984, 1002, 1685,  999,

     1011, 1010, 1017, 1019, 1018, 1022, 1027, 1684, 1028, 1683,
     1682, 1031, 1681, 1029, 1680, 1042, 1679, 1048, 1034, 1678,
     1041, 1049, 1677, 1050, 1052, 1056, 1676, 1675, 1055, 1070,
     1075, 1084, 1077, 1086, 1078, 1095, 1088, 1103, 1107, 1093,
     1105, 1674, 1114, 1113, 1115, 1116, 1108, 1123, 1117, 1119,
     1673, 1136, 1672, 1127, 1124, 1129, 1149,  127, 1145, 1152,
     1146, 1153, 1635, 1787, 1787, 1180,    0,  766, 1144, 1666,
     1665, 1157, 1174, 1663, 1162, 1175, 1181, 1662, 1182, 1186,
     1189, 1190, 1661, 1192, 1197, 1658, 1194, 1205, 1204, 1206,
     1657, 1655, 1654, 1652, 1208, 1196, 1213, 1223, 1224, 1216,

     1228, 1237, 1233, 1650, 1647, 1645,  165, 1644, 1226, 1243,
     1643, 1249, 1253, 1240, 1256, 1639, 1262, 1614, 1255, 1274,
     1259, 1271, 1273, 1260, 1272, 1278, 1283, 1291, 1612, 1286,
     1292, 1302, 1304, 1308, 1289, 1314, 1321, 1313, 1320, 1325,
     1328, 1315, 1334, 1574, 1335,    0,    0, 1312, 1537, 1324,
     1341, 1463, 1339, 1344, 1361, 1462, 1354, 1435, 1342, 1357,
     1340, 1369, 1287, 1368, 1211, 1350, 1383, 1159, 1356, 1372,
     1398, 1079, 1389, 1384,  312, 1385, 1069, 1381, 1392, 1400,
     1396, 1039, 1412, 1413, 1410, 1414, 1420, 1004, 1427, 1424,
     1425,  991,  983,  935, 1428,  921, 1431, 1434, 1429, 1444,

      912,  910, 1456, 1445, 1449,  853,  788,    0, 1455,  784,
     1459,  752,  740, 1464, 1466, 1484, 1485, 1467, 1474,  693,
     1477, 1490,  691,  679,  678, 1495,  675, 1500,  616,  606,
     1473, 1502, 1505,  597,  558, 1503,  556, 1478,  547, 1506,
     1515,  545, 1510, 1526, 1520, 1530, 1531, 1527, 1532, 1533,
     1498, 1551, 1546,  542,  540,  537, 1549, 1552, 1558,  507,
      473, 1554, 1565,  466, 1556,  441, 1563, 1560,  434, 1571,
     1566, 1582,  431, 1586,  411,  376,  371,  366, 1580,  353,
      318, 1584, 1592, 1593, 1598, 1600, 1615,  316, 1608,  304,
     1626, 1629,  300, 1625,  297, 1604, 1632, 1611, 1594,  256,

     1633,  250,  246, 1635,  242,  225,  181, 1787, 1701, 1709,
     1716, 1721, 1723, 1727, 1731, 1735, 1739,  181, 1743,  116,
     1747, 1751, 1756, 1761, 1765, 1769,  109, 1774
    } ;

static yyconst flex_int16_t yy_def[629] =
    {   0,
      608,    1,  609,  609,  608,  608,  608,  608,  608,  610,
      611,  608,  612,  608,  608,  608,  613,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  615,  608,
      608,  608,  608,  608,  610,  608,  610,  611,  616,  617,
      608,  608,  612,  612,  612,  608,  608,  608,  608,  618,
      619,  619,  619,  619,  614,  620,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  621,  622,
      622,  608,  610,  623,  623,  617,  608,  608,  608,  612,
      624,  619,  619,  619,  619,  625,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  626,  622,  608,  622,  623,
      608,  623,  608,  608,  608,  627,  624,  619,  619,  625,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  626,  608,  608,  608,  628,  619,  619,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  628,  619,  619,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  614,  614,  614,  614,  614,  614,  619,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  614,  614,  614,  614,

      614,  614,  614,  614,  614,  614,  614,    0,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608
    } ;

static yyconst flex_uint16_t yy_nxt[1860] =
    {   0,
        6,    7,    8,    9,   10,    6,    6,    6,   11,   12,
       13,   13,   13,   14,   15,    6,   16,   17,   18,   19,
       20,   21,   22,   23,   24,   25,   26,   27,   22,   28,
       29,   30,   31,   32,   22,   33,   34,   35,   36,   37,
       38,   22,   22,   22,    6,   22,   39,   18,   19,   20,
       21,   22,   23,   24,   25,   26,   27,   22,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   22,
       22,   22,   41,   41,   46,   42,   42,   43,   43,   43,
       43,   48,   48,   52,   66,   53,   53,   53,   57,   58,
       49,   49,   49,   60,   66,   46,   62,   55,   66,   66,

       93,   66,   63,   74,   95,   66,   94,   75,   66,   97,
      134,   43,   43,   76,   47,  367,   64,  100,   96,   98,
      608,  101,  156,   77,   99,   62,   55,   46,  113,   93,
      114,   63,   74,   95,   94,   47,   75,  153,   97,  134,
       66,   66,   76,   66,   64,   66,  100,   96,   98,  101,
      102,   77,   99,   67,  103,   66,   68,  113,  114,  115,
      104,   69,  143,   70,   66,  116,  153,   47,   71,   72,
      268,   73,  441,  132,  154,  133,   66,  475,   66,  102,
       66,  110,   67,  103,  155,   68,  190,  151,  115,  104,
       69,  165,   70,  116,   66,  111,   71,   72,  268,   73,

       66,  112,  132,  154,  133,   78,   66,  139,  139,  139,
      110,  117,   79,  155,  190,  118,   80,   48,   48,   81,
      165,   66,   82,  141,  111,  119,  608,  608,  608,  112,
      120,   49,   49,   49,   78,  147,  147,  147,   66,  192,
      117,   79,   66,  145,  118,   80,   66,  148,   81,  163,
       82,   66,  141,   66,  119,   66,   83,   66,  120,   66,
       84,  157,   66,   66,   85,  169,  158,  135,  192,   66,
       86,  136,  145,   87,  137,  138,  148,   52,  163,   53,
       53,   53,  149,  149,  608,   83,  150,  150,  150,   84,
      157,   55,   66,   85,  169,  158,  135,   66,   66,   86,

      136,   87,   66,  137,  138,  161,   66,   88,  159,  168,
       66,   66,   66,   66,   66,   66,  160,   66,   89,  171,
       55,   90,  166,  527,   91,   66,  162,   92,  170,   66,
      164,   66,   66,   66,  161,  167,   88,  159,  168,  172,
      173,  177,   66,   66,  160,   66,   66,   89,  171,   66,
       90,  166,   91,  206,  162,   92,   66,  170,  164,  195,
       66,  105,  185,  167,  191,  106,   66,  172,  173,  107,
      177,  184,   66,  178,   66,  108,  174,  175,  179,   66,
       66,  109,  206,   66,   66,  176,  242,  195,  180,   66,
      105,  185,   66,  191,  106,  181,   66,  182,  107,  184,

      183,  178,  188,  186,  108,  174,  175,  179,  189,  109,
       66,  193,  187,  176,   66,  242,   66,  180,   66,  121,
       66,  269,  122,  181,   66,  182,   66,  201,  183,  123,
       66,  188,  186,   66,  124,  125,  189,  194,   66,  126,
      193,  187,  203,  196,   66,  200,   66,   66,  121,  202,
      269,  122,   66,  204,   66,  205,  201,  209,  123,   66,
      197,   66,  124,  125,  210,   66,  194,  126,   66,  211,
      203,  196,   66,  127,  200,  198,  199,   66,  202,   66,
      128,  212,  204,  214,  205,  209,   66,  129,   66,  197,
      130,   66,   66,  210,  213,   66,  207,  131,  211,   66,

      208,   66,  127,  198,  199,   66,  218,  215,  230,  128,
      212,  214,  216,  217,  220,   66,  129,   66,  130,   66,
       66,  243,   66,  213,  207,  131,  219,  238,  208,   66,
      231,   66,  221,  222,   66,  218,  215,  230,  236,   66,
      216,   66,  217,  220,  239,   66,  247,  237,  240,  243,
       66,   66,  324,   66,  219,   66,  238,  241,   66,  231,
       66,  221,  222,   66,  253,  246,   66,  236,  223,   66,
      224,   66,  239,   66,  225,  247,  237,  240,  244,  226,
      227,  324,  232,  228,   66,  241,   66,  229,  233,  234,
      235,   66,  248,  253,  246,  254,   66,  223,  245,  224,

      139,  139,  139,  225,  251,  259,   66,  244,  226,  227,
       66,  232,  228,  252,   66,  229,  233,  234,  235,   66,
      255,  248,  249,  272,  254,   66,  245,   66,  250,   66,
      258,  261,  261,  251,  259,  262,  262,  262,  147,  147,
      147,  252,  265,  265,  265,  271,   66,  280,  255,   66,
      148,  249,  272,  263,  263,   66,  250,  264,  264,  264,
      608,   66,  150,  150,  150,   66,  273,  281,  275,   66,
       66,   66,   66,  276,  271,  280,   66,   66,  277,  148,
       66,  287,   66,  274,   66,  278,  279,  288,   66,  285,
       66,   66,   66,   66,  282,  273,  281,  275,  286,  290,

      283,  276,  289,   66,   66,   66,   66,  277,   66,  284,
      287,  274,  291,   66,  278,  279,  288,  292,  285,  293,
       66,   66,  282,  294,   66,  297,   66,  286,  290,  283,
      289,  296,   66,  295,   66,   66,   66,  284,   66,   66,
      301,  291,  300,   66,  298,  292,   66,  305,  293,  299,
       66,  302,  294,   66,  297,  306,  303,  310,   66,  296,
      304,   66,  295,   66,   66,   66,  309,  307,   66,  301,
      312,  300,  298,  313,   66,   66,  305,  308,  299,  302,
       66,  311,  316,   66,  306,  303,  310,  314,  304,   66,
       66,  315,  319,   66,  317,  309,  307,   66,   66,  312,

       66,   66,  313,  447,  318,   66,  308,  322,  323,  320,
      311,  316,   66,  321,   66,  325,  314,   66,   66,  315,
      327,  319,  328,  317,  326,   66,   66,  330,   66,   66,
      332,  447,  318,   66,   66,   66,  322,  323,  320,   66,
       66,   66,  321,  333,  325,  329,  339,  331,   66,  327,
      334,  328,   66,  326,  335,  336,  330,  338,  337,  332,
       66,   66,  342,   66,  340,  343,   66,   66,   66,   66,
      350,   66,  333,  347,  329,  339,  331,   66,  349,  334,
      353,  346,  335,   66,  336,  341,  338,  337,   66,  344,
      342,  345,  340,  348,  343,   66,   66,  351,   66,  350,

       66,  355,  347,   66,   66,   66,  352,  349,  356,  353,
      346,  357,  368,  341,  354,  360,   66,  344,   66,  345,
      369,  359,  348,   66,  358,   66,  351,  361,  362,   66,
      355,  366,  366,  366,   66,  352,  356,  262,  262,  262,
      357,  368,  370,  354,  360,  264,  264,  264,   66,  369,
      359,  371,  358,   66,   66,  361,   66,  362,  264,  264,
      264,  265,  265,  265,   66,  375,  373,   66,   66,   66,
      370,  372,  374,  377,   66,   66,   66,   66,   66,  371,
      380,   66,   66,   66,  378,  376,   66,   66,   66,  385,
      382,  389,   66,  381,  375,  373,   66,   66,  379,  386,

      372,  374,  377,   66,   66,  383,  384,   66,  390,  380,
      387,  391,   66,  378,  376,   66,  392,   66,  385,  382,
      389,  393,  381,   66,   66,  388,  379,  394,  386,  396,
       66,   66,   66,  383,  384,   66,  395,  390,  387,  391,
       66,   66,   66,  397,   66,  392,  403,   66,  398,  393,
      399,  402,   66,  388,   66,   66,  394,  401,  396,  400,
      404,   66,   66,   66,  395,   66,  405,  406,   66,   66,
      408,  409,  397,  410,  407,  403,  412,  398,  413,  399,
      402,  414,   66,   66,  411,  401,  415,  400,   66,  404,
       66,   66,   66,  417,  405,  419,  406,   66,  408,   66,

      409,   66,  410,  407,  420,  412,   66,  413,   66,  423,
      414,  416,  411,  421,  422,  415,   66,  418,   66,  426,
       66,   66,  417,  424,  419,  425,   66,   66,   66,   66,
       66,  427,   66,  420,  432,  434,   66,   66,  423,  416,
       66,  421,   66,  422,  428,  433,  418,  431,  426,   66,
      429,  439,  424,  430,  425,  435,  436,  437,   66,   66,
      427,  438,   66,  432,  434,   66,   66,  440,  444,  448,
       66,  442,   66,  428,  433,   66,  431,  443,  429,  445,
      439,  430,  449,  435,  451,  436,  437,   66,   66,  438,
      366,  366,  366,  450,   66,   66,  440,  444,  448,   66,

      442,  453,   66,   66,  454,   66,  443,   66,  445,   66,
       66,  449,  452,  451,  458,  459,  460,   66,   66,   66,
      456,   66,  450,  455,   66,  465,   66,  457,  463,   66,
      453,  461,  466,  454,  464,  462,   66,   66,  470,   66,
      452,   66,  469,  458,  459,  460,   66,  468,  471,  456,
       66,  455,  476,   66,  465,  457,   66,  463,  467,  473,
      461,  466,   66,  464,  462,  472,   66,  470,   66,   66,
      474,  469,   66,   66,  477,   66,  468,  471,  480,  481,
      478,  476,  479,  482,   66,   66,   66,   66,  473,  486,
      485,   66,  483,  472,  484,  487,   66,  488,  474,   66,

       66,  489,   66,  477,   66,   66,  480,  498,  481,  478,
      490,  479,  482,  492,  491,   66,  494,   66,  486,  485,
      483,   66,  493,  484,  487,  488,   66,   66,   66,  497,
      489,  495,  499,   66,   66,  501,  498,   66,   66,  490,
      496,   66,  492,  491,  503,  494,  505,   66,   66,  508,
      493,  500,   66,   66,   66,   66,  502,   66,  497,  517,
      495,  499,  509,   66,  501,  504,  507,   66,  496,   66,
       66,  506,  510,  503,   66,  505,  511,  508,  516,  512,
      500,   66,   66,  513,  502,   66,  522,  514,  517,  518,
      509,  515,  520,  504,   66,  507,   66,   66,   66,  506,

      519,  510,   66,  521,  511,   66,  516,  512,  523,   66,
      526,   66,  513,   66,  530,  522,  514,  529,  518,  515,
      520,  524,  532,   66,  525,   66,   66,   66,  528,  519,
      533,  531,  521,   66,  536,  534,  523,   66,   66,  526,
       66,   66,   66,  530,   66,  529,  535,   66,   66,  540,
      524,  532,  525,  538,  543,  539,  528,   66,   66,  533,
      531,  537,   66,  536,  534,  541,  544,  542,   66,   66,
      545,  547,   66,  548,  535,   66,   66,   66,  540,   66,
       66,  550,  538,  543,  539,  546,   66,   66,  552,  537,
       66,   66,  549,  541,  544,  542,  551,   66,   66,  545,

      547,  561,  548,   66,  555,  556,  553,  554,   66,  557,
      550,   66,  558,   66,  546,   66,   66,  552,   66,   66,
      549,  565,  560,   66,  563,  551,  562,  559,   66,  576,
      561,  564,  555,   66,  556,  553,  554,  567,  557,   66,
       66,  558,  566,   66,   66,   66,   66,  568,  569,  565,
       66,  560,  571,  563,  574,  562,  559,  570,  576,   66,
      564,  572,   66,  573,   66,   66,  567,   66,  575,   66,
      566,   66,  577,   66,  584,  568,   66,  569,   66,   66,
      579,  571,  578,  574,   66,  570,  586,   66,  580,  581,
      572,  573,  582,   66,  583,   66,  575,   66,  585,   66,

      591,  577,  588,  584,  589,   66,   66,   66,  587,  579,
      578,   66,  594,   66,  593,  586,  580,   66,  581,  592,
      582,   66,  590,  583,   66,   66,  585,   66,   66,  591,
      588,  605,  596,  589,  595,  602,  587,  597,   66,   66,
      598,  594,   66,  593,  599,   66,   66,  592,   66,  604,
      590,  600,   66,  603,  601,  606,   66,   66,   66,  605,
       66,  596,  595,   66,  602,   66,  597,   66,   66,  598,
       66,   66,  607,  599,   66,   66,   66,  604,   66,   66,
      600,  364,  603,  601,  606,   66,   66,   66,   66,   66,
       66,   66,   66,   66,   66,   66,   66,   66,   66,   66,

      607,   40,   40,   40,   40,   40,   40,   40,   40,   45,
       45,   45,   45,   45,   45,   45,   45,   50,   66,   50,
       66,  266,   50,   54,   54,  365,  258,   54,   61,   61,
       65,   65,  364,   65,  140,   66,   66,  140,  144,   66,
       66,  144,  146,   66,   66,  146,  152,   66,   66,  152,
      256,   66,   66,  256,  257,   66,   66,  257,  257,  260,
       66,  266,  260,  267,  267,  258,   66,  267,  270,   66,
       66,  270,  363,   66,  608,  363,  363,  446,  142,   66,
      446,   59,   56,   51,   44,  608,    5,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,

      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608
    } ;

static yyconst flex_int16_t yy_chk[1860] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,   10,    3,    4,    7,    7,    8,
        8,   11,   11,   13,   24,   13,   13,   13,   15,   15,
       11,   11,   11,   17,   19,   45,   17,   13,   27,   25,

       24,   26,   17,   19,   25,   37,   24,   19,   31,   26,
       37,   43,   43,   19,   10,  627,   17,   27,   25,   26,
       47,   27,  620,   19,   26,   17,   13,  143,   31,   24,
       31,   17,   19,   25,   24,   45,   19,   62,   26,   37,
      358,   28,   19,   32,   17,   18,   27,   25,   26,   27,
       28,   19,   26,   18,   28,   36,   18,   31,   31,   32,
       28,   18,   47,   18,   90,   32,   62,  143,   18,   18,
      153,   18,  358,   36,   63,   36,   30,  407,  407,   28,
       73,   30,   18,   28,   64,   18,   90,  618,   32,   28,
       18,   73,   18,   32,  607,   30,   18,   18,  153,   18,

       20,   30,   36,   63,   36,   20,   33,   39,   39,   39,
       30,   33,   20,   64,   90,   33,   20,   48,   48,   20,
       73,   92,   20,   39,   30,   33,   48,   48,   48,   30,
       33,   49,   49,   49,   20,   52,   52,   52,  606,   92,
       33,   20,   71,   49,   33,   20,   76,   52,   20,   71,
       20,   21,   39,   67,   33,  605,   21,   68,   33,  603,
       21,   67,   38,  602,   21,   76,   68,   38,   92,  600,
       21,   38,   49,   21,   38,   38,   52,   53,   71,   53,
       53,   53,   55,   55,   55,   21,   55,   55,   55,   21,
       67,   53,   69,   21,   76,   68,   38,   70,   75,   21,

       38,   21,   23,   38,   38,   70,   72,   23,   69,   75,
      595,   74,   78,  593,   79,   80,   69,  590,   23,   79,
       53,   23,   74,  475,   23,  475,   70,   23,   78,  588,
       72,  581,   82,   95,   70,   74,   23,   69,   75,   79,
       80,   82,  104,   87,   69,   91,   86,   23,   79,   83,
       23,   74,   23,  104,   70,   23,   29,   78,   72,   95,
       81,   29,   87,   74,   91,   29,  580,   79,   80,   29,
       82,   86,   84,   83,   85,   29,   81,   81,   84,  578,
      127,   29,  104,   89,  577,   81,  127,   95,   84,  576,
       29,   87,   93,   91,   29,   84,   88,   85,   29,   86,

       85,   83,   89,   88,   29,   81,   81,   84,   89,   29,
       34,   93,   88,   81,  100,  127,  102,   84,   94,   34,
       96,  155,   34,   84,  575,   85,   99,  100,   85,   34,
      101,   89,   88,  106,   34,   34,   89,   94,  103,   34,
       93,   88,  102,   96,  573,   99,  107,  569,   34,  101,
      155,   34,   98,  103,  566,  103,  100,  106,   34,  111,
       98,  108,   34,   34,  107,  109,   94,   34,   35,  108,
      102,   96,  105,   35,   99,   98,   98,  110,  101,  564,
       35,  109,  103,  111,  103,  106,  561,   35,  113,   98,
       35,  112,  119,  107,  110,  116,  105,   35,  108,  128,

      105,  115,   35,   98,   98,  114,  115,  112,  119,   35,
      109,  111,  113,  114,  116,  117,   35,  120,   35,  122,
      560,  128,  124,  110,  105,   35,  115,  124,  105,  123,
      120,  125,  117,  117,  126,  115,  112,  119,  122,  132,
      113,  219,  114,  116,  124,  131,  132,  123,  125,  128,
      556,  136,  219,  555,  115,  554,  124,  126,  542,  120,
      539,  117,  117,  118,  136,  131,  121,  122,  118,  537,
      118,  535,  124,  130,  118,  132,  123,  125,  130,  118,
      118,  219,  121,  118,  133,  126,  137,  118,  121,  121,
      121,  135,  133,  136,  131,  137,  138,  118,  130,  118,

      139,  139,  139,  118,  135,  141,  134,  130,  118,  118,
      534,  121,  118,  135,  160,  118,  121,  121,  121,  530,
      138,  133,  134,  160,  137,  171,  130,  158,  134,  529,
      141,  145,  145,  135,  141,  145,  145,  145,  147,  147,
      147,  135,  149,  149,  149,  158,  167,  171,  138,  172,
      147,  134,  160,  148,  148,  166,  134,  148,  148,  148,
      150,  164,  150,  150,  150,  168,  164,  172,  166,  169,
      170,  173,  175,  167,  158,  171,  177,  179,  168,  147,
      176,  177,  178,  164,  174,  169,  170,  178,  527,  175,
      180,  525,  524,  182,  173,  164,  172,  166,  176,  180,

      174,  167,  179,  185,  523,  181,  520,  168,  187,  174,
      177,  164,  181,  184,  169,  170,  178,  182,  175,  184,
      188,  189,  173,  185,  186,  188,  194,  176,  180,  174,
      179,  187,  191,  186,  193,  192,  196,  174,  197,  201,
      193,  181,  192,  195,  189,  182,  198,  197,  184,  191,
      200,  194,  185,  513,  188,  198,  195,  201,  199,  187,
      196,  203,  186,  202,  204,  512,  200,  199,  206,  193,
      203,  192,  189,  204,  205,  207,  197,  199,  191,  194,
      212,  202,  207,  213,  198,  195,  201,  205,  196,  209,
      218,  206,  213,  215,  209,  200,  199,  510,  217,  203,

      216,  507,  204,  368,  212,  220,  199,  217,  218,  215,
      202,  207,  222,  216,  223,  220,  205,  221,  225,  206,
      222,  213,  223,  209,  221,  227,  224,  225,  226,  229,
      227,  368,  212,  233,  228,  236,  217,  218,  215,  230,
      231,  234,  216,  228,  220,  224,  233,  226,  232,  222,
      228,  223,  244,  221,  229,  230,  225,  232,  231,  227,
      237,  235,  236,  241,  234,  237,  506,  238,  239,  243,
      244,  246,  228,  241,  224,  233,  226,  242,  243,  228,
      246,  239,  229,  249,  230,  235,  232,  231,  245,  238,
      236,  238,  234,  242,  237,  247,  248,  245,  250,  244,

      251,  248,  241,  252,  253,  254,  245,  243,  249,  246,
      239,  250,  268,  235,  247,  253,  255,  238,  271,  238,
      269,  252,  242,  502,  251,  501,  245,  254,  255,  272,
      248,  261,  261,  261,  496,  245,  249,  262,  262,  262,
      250,  268,  271,  247,  253,  263,  263,  263,  494,  269,
      252,  272,  251,  274,  275,  254,  276,  255,  264,  264,
      264,  265,  265,  265,  273,  276,  274,  277,  280,  281,
      271,  273,  275,  280,  282,  283,  284,  285,  292,  272,
      283,  286,  287,  288,  281,  277,  290,  295,  289,  288,
      285,  292,  293,  284,  276,  274,  493,  297,  282,  289,

      273,  275,  280,  291,  492,  286,  287,  296,  293,  283,
      290,  295,  300,  281,  277,  298,  296,  488,  288,  285,
      292,  297,  284,  302,  301,  291,  282,  298,  289,  301,
      303,  305,  304,  286,  287,  306,  300,  293,  290,  295,
      307,  309,  314,  302,  312,  296,  309,  319,  303,  297,
      304,  307,  482,  291,  321,  316,  298,  306,  301,  305,
      312,  318,  322,  324,  300,  325,  314,  316,  329,  326,
      319,  321,  302,  321,  318,  309,  324,  303,  325,  304,
      307,  326,  477,  330,  322,  306,  329,  305,  331,  312,
      333,  335,  472,  331,  314,  333,  316,  332,  319,  334,

      321,  337,  321,  318,  334,  324,  340,  325,  336,  337,
      326,  330,  322,  335,  336,  329,  338,  332,  341,  340,
      339,  347,  331,  338,  333,  339,  344,  343,  345,  346,
      349,  341,  350,  334,  347,  349,  348,  355,  337,  330,
      354,  335,  356,  336,  343,  348,  332,  346,  340,  352,
      344,  356,  338,  345,  339,  350,  352,  354,  359,  361,
      341,  355,  357,  347,  349,  360,  362,  357,  361,  369,
      372,  359,  468,  343,  348,  375,  346,  360,  344,  362,
      356,  345,  372,  350,  375,  352,  354,  373,  376,  355,
      366,  366,  366,  373,  377,  379,  357,  361,  369,  380,

      359,  377,  381,  382,  379,  384,  360,  387,  362,  396,
      385,  372,  376,  375,  384,  385,  387,  389,  388,  390,
      381,  395,  373,  380,  465,  396,  397,  382,  390,  400,
      377,  388,  397,  379,  395,  389,  398,  399,  400,  409,
      376,  401,  399,  384,  385,  387,  403,  398,  400,  381,
      402,  380,  409,  414,  396,  382,  410,  390,  397,  402,
      388,  397,  412,  395,  389,  401,  413,  400,  419,  415,
      403,  399,  421,  424,  410,  417,  398,  400,  414,  415,
      412,  409,  413,  417,  422,  425,  423,  420,  402,  422,
      421,  426,  419,  401,  420,  423,  427,  424,  403,  430,

      463,  425,  435,  410,  428,  431,  414,  435,  415,  412,
      426,  413,  417,  428,  427,  432,  431,  433,  422,  421,
      419,  434,  430,  420,  423,  424,  438,  436,  442,  434,
      425,  432,  436,  439,  437,  438,  435,  450,  440,  426,
      433,  441,  428,  427,  440,  431,  442,  443,  445,  448,
      430,  437,  453,  461,  451,  459,  439,  454,  434,  461,
      432,  436,  450,  466,  438,  441,  445,  457,  433,  469,
      460,  443,  451,  440,  455,  442,  453,  448,  459,  454,
      437,  464,  462,  455,  439,  470,  469,  455,  461,  462,
      450,  457,  466,  441,  478,  445,  467,  474,  476,  443,

      464,  451,  473,  467,  453,  479,  459,  454,  470,  481,
      474,  471,  455,  480,  479,  469,  455,  478,  462,  457,
      466,  471,  481,  485,  473,  483,  484,  486,  476,  464,
      483,  480,  467,  487,  486,  484,  470,  490,  491,  474,
      489,  495,  499,  479,  497,  478,  485,  498,  458,  491,
      471,  481,  473,  489,  498,  490,  476,  500,  504,  483,
      480,  487,  505,  486,  484,  495,  499,  497,  509,  503,
      500,  504,  511,  505,  485,  456,  452,  514,  491,  515,
      518,  511,  489,  498,  490,  503,  531,  519,  515,  487,
      521,  538,  509,  495,  499,  497,  514,  516,  517,  500,

      504,  531,  505,  522,  518,  519,  516,  517,  526,  521,
      511,  551,  522,  528,  503,  532,  536,  515,  533,  540,
      509,  538,  528,  543,  533,  514,  532,  526,  541,  551,
      531,  536,  518,  545,  519,  516,  517,  541,  521,  544,
      548,  522,  540,  546,  547,  549,  550,  543,  544,  538,
      449,  528,  546,  533,  549,  532,  526,  545,  551,  553,
      536,  547,  557,  548,  552,  558,  541,  562,  550,  565,
      540,  559,  552,  568,  565,  543,  567,  544,  563,  571,
      557,  546,  553,  549,  570,  545,  568,  444,  558,  559,
      547,  548,  562,  579,  563,  572,  550,  582,  567,  574,

      579,  552,  571,  565,  572,  583,  584,  599,  570,  557,
      553,  585,  584,  586,  583,  568,  558,  596,  559,  582,
      562,  589,  574,  563,  598,  429,  567,  418,  587,  579,
      571,  599,  586,  572,  585,  596,  570,  587,  594,  591,
      589,  584,  592,  583,  591,  597,  601,  582,  604,  598,
      574,  592,  416,  597,  594,  601,  411,  408,  406,  599,
      405,  586,  585,  404,  596,  394,  587,  393,  392,  589,
      391,  386,  604,  591,  383,  378,  374,  598,  371,  370,
      592,  363,  597,  594,  601,  353,  351,  342,  328,  327,
      323,  320,  317,  315,  313,  311,  310,  308,  299,  294,

      604,  609,  609,  609,  609,  609,  609,  609,  609,  610,
      610,  610,  610,  610,  610,  610,  610,  611,  279,  611,
      278,  267,  611,  612,  612,  259,  257,  612,  613,  613,
      614,  614,  256,  614,  615,  240,  214,  615,  616,  211,
      210,  616,  617,  208,  190,  617,  619,  183,  165,  619,
      621,  163,  162,  621,  622,  161,  159,  622,  622,  623,
      157,  151,  623,  624,  624,  140,  129,  624,  625,   97,
       77,  625,  626,   65,   54,  626,  626,  628,   42,   22,
      628,   16,   14,   12,    9,    5,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,

      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608,  608,
      608,  608,  608,  608,  608,  608,  608,  608,  608
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
#line 2 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
#ifdef CMAKE_GENERATED_GRAMMAR
	#include "bissphinxql.h"
#else
	#include "yysphinxql.h"
#endif

#if USE_WINDOWS
#pragma warning(push,1)
#endif

// warning, lexer generator dependent!
// this macro relies on that in flex yytext points to the actual location in the buffer
#define YYSTOREBOUNDS \
	{ \
		lvalp->m_iStart = yytext - pParser->m_pBuf; \
		lvalp->m_iEnd = lvalp->m_iStart + yyleng; \
		pParser->m_pLastTokenStart = yytext; \
	}


#line 1081 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/build/config/flexsphinxql.c"

#define INITIAL 0
#define ccomment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * _in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * _out_str ,yyscan_t yyscanner );

yy_size_t yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int _line_number ,yyscan_t yyscanner );

int yyget_column  (yyscan_t yyscanner );

void yyset_column (int _column_no ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	{
#line 35 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"


#line 1344 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/build/config/flexsphinxql.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 609 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1787 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 37 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ BEGIN(ccomment); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 38 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 39 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 41 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ADD; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 42 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AGENT; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 43 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ALL; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 44 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ALTER; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 45 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AND; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 46 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ANY; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 47 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AS; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 48 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ASC; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 49 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTACH; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 50 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTRIBUTES; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 51 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AVG; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 52 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BEGIN; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 53 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BETWEEN; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 54 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BIGINT; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 55 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BOOL; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 56 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BY; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 57 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CALL; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 58 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CHARACTER; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 59 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CHUNK; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 60 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CLUSTER; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 61 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLLATE; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 62 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLLATION; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 63 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLUMN; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 64 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMIT; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 65 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMITTED; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 66 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COUNT; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 67 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CREATE; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 68 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DATABASES; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 69 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DEBUG; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 70 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DELETE; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 71 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESC; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 72 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESCRIBE; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 73 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DISTINCT; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 74 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DIV; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 75 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DOUBLE; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 76 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DROP; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 77 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FACET; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 78 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FALSE; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 79 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLOAT; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 80 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLUSH; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 81 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FOR; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 82 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FROM; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 83 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FUNCTION; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 84 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GLOBAL; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 85 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 86 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUPBY; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 87 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP_CONCAT; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 88 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_HAVING; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 89 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_HOSTNAMES; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 90 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ID; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 91 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IN; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 92 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INDEX; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 93 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INDEXES; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 94 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INDEXOF; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 95 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INSERT; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 96 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTEGER; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 97 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INT; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 98 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTO; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 99 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IS; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 100 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ISOLATION; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 101 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_JOIN; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 102 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_JSON; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 103 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LEVEL; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 104 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIKE; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 105 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LOGS; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 106 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIMIT; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 107 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MATCH; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 108 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MAX; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 109 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_META; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 110 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MIN; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 111 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MOD; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 112 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MULTI; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 113 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MULTI64; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 114 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NAMES; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 115 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NOT; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 116 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NULL; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 117 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTION; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 118 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTIMIZE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 119 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OR; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 120 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ORDER; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 121 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLAN; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 122 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLUGIN; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 123 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLUGINS; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 124 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PROFILE; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 125 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAMCHUNK; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 126 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAND; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 127 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_READ; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 128 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REGEX; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 129 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RECONFIGURE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 130 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RELOAD; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 131 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPEATABLE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 132 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPLACE; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 133 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REMAP; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 134 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RETURNS; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 135 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ROLLBACK; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 136 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RTINDEX; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 137 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SELECT; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 138 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SERIALIZABLE; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 139 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SET; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 140 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SETTINGS; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 141 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SESSION; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 142 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SHOW; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 143 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SONAME; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 144 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_START; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 145 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STATUS; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 146 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STRING; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 147 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUM; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 148 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSFILTERS; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 149 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLE; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 150 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLES; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 151 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_THREADS; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 152 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TO; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 153 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRANSACTION; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 154 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 155 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUNCATE; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 156 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TYPE; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 157 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UNCOMMITTED; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 158 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UPDATE; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 159 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VALUES; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 160 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VARIABLES; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 161 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSVAR; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 162 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WARNINGS; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 163 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WEIGHT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 164 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WHERE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 165 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WITH; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 166 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WITHIN; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 168 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 169 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 170 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LTE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 171 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GTE; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 172 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return '='; }
	YY_BREAK
case 135:
/* rule 135 can match eol */
YY_RULE_SETUP
#line 174 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; pParser->m_pLastTokenStart = yytext; lvalp->m_iValue = ( (SphAttr_t)lvalp->m_iStart<<32 ) | ( lvalp->m_iEnd-lvalp->m_iStart ); return TOK_QUOTED_STRING; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 176 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 177 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_DOT_NUMBER; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 178 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUBKEY; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 179 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 180 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iValue = (int64_t)strtoull ( yytext, NULL, 10 ); return TOK_CONST_INT; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 182 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 183 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 184 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATIDENT; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 185 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IDENT; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 186 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BAD_NUMERIC; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 187 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_USERVAR; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 188 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSVAR; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 189 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SYSVAR; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 190 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_ID; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 191 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_IDENT; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 192 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; return TOK_IDENT; } // allow `123xyz` column names
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 193 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IDENT; }
	YY_BREAK
case 153:
/* rule 153 can match eol */
YY_RULE_SETUP
#line 195 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ ; }
	YY_BREAK
case 154:
/* rule 154 can match eol */
YY_RULE_SETUP
#line 196 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUBKEY; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 197 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
{ YYSTOREBOUNDS; return yytext[0]; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 199 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"
ECHO;
	YY_BREAK
#line 2184 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/build/config/flexsphinxql.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ccomment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	yy_size_t number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 609 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 609 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 608);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 199 "/home/gitlab-runner/builds/ae04cf72/0/manticoresearch/dev/src/sphinxql.l"



// warning, lexer generator dependent!
// flex inserts trailing zero as needed into the buffer when lexing
// but we need that rolled back when doing error reporting from yyerror
void yylex_unhold ( yyscan_t yyscanner )
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( YY_CURRENT_BUFFER )
	{
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
	}
}

#if USE_WINDOWS
#pragma warning(pop)
#endif

